==> jetlog-0.5.0.tar.gz: test/multi_filter_test.dart <==
import 'package:test/test.dart';
import 'package:jetlog/jetlog.dart';
import 'package:jetlog/filters.dart' show MultiFilter;
import 'package:jetlog/src/record_impl.dart';

class _TestFilter1 extends Filter {
  @override
  bool filter(Record record) => record.name == 'Test';
}

class _TestFilter2 extends Filter {
  @override
  bool filter(Record record) => record.message == 'Test';
}

void main() {
  group('MultiFilter', () {
    test('allows any record when no filters set', () {
      final filter = MultiFilter([]);

      final record1 = RecordImpl(
          timestamp: DateTime.now(),
          name: 'abc',
          level: Level.info,
          message: 'abc',
          fields: []);
      final record2 = RecordImpl(
          timestamp: DateTime.now(),
          name: 'cba',
          level: Level.info,
          message: 'baz',
          fields: []);
      final record3 = RecordImpl(
          timestamp: DateTime.now(),
          name: 'foo',
          level: Level.info,
          message: 'bar',
          fields: []);

      expect(filter.filter(record1), isTrue);
      expect(filter.filter(record2), isTrue);
      expect(filter.filter(record3), isTrue);
    });

    test('delegates record to all filters', () {
      final filter1 = _TestFilter1();
      final filter2 = _TestFilter2();
      final filter = MultiFilter({filter1, filter2});

      final record1 = RecordImpl(
          timestamp: DateTime.now(),
          name: 'Test',
          level: Level.info,
          message: 'Test',
          fields: []);
      final record2 = RecordImpl(
          timestamp: DateTime.now(),
          name: 'Test',
          level: Level.info,
          message: 'Test2',
          fields: []);
      final record3 = RecordImpl(
          timestamp: DateTime.now(),
          name: 'Test2',
          level: Level.info,
          message: 'Test',
          fields: []);


      expect(filter.filter(record1), isTrue);
      expect(filter.filter(record2), isFalse);
      expect(filter.filter(record3), isFalse);
    });
  });
}

==> jetlog-1.0.0-rc.0.tar.gz: test/multi_filter_test.dart <==
import 'package:jetlog/filters.dart' show MultiFilter;
import 'package:jetlog/jetlog.dart';
import 'package:jetlog/src/record_impl.dart';
import 'package:test/test.dart';

class _TestFilter1 {
  bool call(Record record) => record.name == 'Test';
}

class _TestFilter2 {
  bool call(Record record) => record.message == 'Test';
}

void main() {
  group('MultiFilter', () {
    test('allows any record when no filters set', () {
      final filter = MultiFilter([]);

      final record1 = RecordImpl(
          timestamp: DateTime.now(),
          name: 'abc',
          level: Level.info,
          message: 'abc',
          fields: []);
      final record2 = RecordImpl(
          timestamp: DateTime.now(),
          name: 'cba',
          level: Level.info,
          message: 'baz',
          fields: []);
      final record3 = RecordImpl(
          timestamp: DateTime.now(),
          name: 'foo',
          level: Level.info,
          message: 'bar',
          fields: []);

      expect(filter.call(record1), isTrue);
      expect(filter.call(record2), isTrue);
      expect(filter.call(record3), isTrue);
    });

    test('delegates record to all filters', () {
      final filter1 = _TestFilter1();
      final filter2 = _TestFilter2();
      final filter = MultiFilter({filter1, filter2});

      final record1 = RecordImpl(
          timestamp: DateTime.now(),
          name: 'Test',
          level: Level.info,
          message: 'Test',
          fields: []);
      final record2 = RecordImpl(
          timestamp: DateTime.now(),
          name: 'Test',
          level: Level.info,
          message: 'Test2',
          fields: []);
      final record3 = RecordImpl(
          timestamp: DateTime.now(),
          name: 'Test2',
          level: Level.info,
          message: 'Test',
          fields: []);

      expect(filter.call(record1), isTrue);
      expect(filter.call(record2), isFalse);
      expect(filter.call(record3), isFalse);
    });
  });
}
